:mod:`rdial`
============

``rdial`` is a simple way to track the time you spend on tasks.  It tracks the
name of a task, its start time and its duration… nothing more.

It is written in Python_, and requires v2.6 or later.  :mod:`rdial` is released
under the `GPL v3`_.

:Git repository:  https://github.com/JNRowe/rdial/
:Issue tracker:  https://github.com/JNRowe/rdial/issues/
:Contributors:  https://github.com/JNRowe/rdial/contributors/

Contents
--------

.. toctree::
   :maxdepth: 2

   background
   usage
   getting_started
   rdial manpage <rdial.1>
   config
   faq
   taskbars
   alternatives
   release
   api/index

Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _Python: http://www.python.org/
.. _GPL v3: http://www.gnu.org/licenses/
